Module: Microsandbox::Binaries

Defined in:
lib/microsandbox/binaries.rb,
lib/microsandbox/binaries/version.rb

Defined Under Namespace

Classes: Error

Constant Summary collapse

VERSION =
"0.1.0"

Class Method Summary collapse

Class Method Details

.helloObject

Keep a tiny callable API so the namespace is useful in smoke tests without pretending this package already installs Microsandbox runtime binaries.



13
14
15
# File 'lib/microsandbox/binaries.rb', line 13

def hello
  "hello from microsandbox-binaries"
end